@@ -610,6 +610,8 @@ void segatex::segatex_show_interface()
 					vector<string>::iterator p_accv, p_accv_end;
 					vector<string> v_tmp_domain;
 					vector<string>::iterator p_tmp_domain, p_tmp_domain_end;
+					vector<string> v_dollar_2_domain;
+					vector<string>::iterator p_dollar_2_domain, p_dollar_2_domain_end;
 
 
 					vector<string> v_allow_first;
@@ -733,8 +735,8 @@ void segatex::segatex_show_interface()
 					p2_v_end = unique(v2.begin(),v2.end());
 					const char* m_pre = "(.*):([^[:space:]]*)([:space:])?";
 					const char* m_interface_pre = "[a-z]([^[:space:]]*):([^[:space:]]*)([:space:])?";
-					const char* m_domain_pre = "[a-z0-9_]*_t";
-					const char* m_tclass_pre = "[a-z0-9_]*_t:";
+					const char* m_domain_pre = "[A-Za-z0-9_]*_t";
+					const char* m_tclass_pre = "[A-Za-z0-9_]*_t:";
 					//changed here at segatex2.11
 					const char* m_objclass_pre = ":[a-z0-9_]*([^[:space:]]*)([:space:])?";
 					const char* m_acc = "\\{(.*)\\}";
@@ -769,8 +771,10 @@ void segatex::segatex_show_interface()
 						cmatch what;
 						if(regex_search(source_m,what,m_domain_pre_exp)){
 							source_domain_pre  = what[0];
+							//2.12ɮäѤꤳѤΤɬפä
+							v_tmp_domain.push_back(source_domain_pre.c_str());
 							/*for debug*/
-						//	os_policy << source_domain_pre << endl;	
+							//os_policy << source_domain_pre << endl;	
 						} 
 						if(regex_search(source_m,what,m_tclass_pre_exp)){
 							source_tclass_pre  = what[0];
@@ -778,6 +782,8 @@ void segatex::segatex_show_interface()
 							string blank_str="";
 							source_tclass_pre=source_tclass_pre.replace(length - 1,1,blank_str);
 							/*for debug*/
+							//2.12ɮäѤꤳѤΤɬפä
+							v_tmp_domain.push_back(source_domain_pre.c_str());
 							//os_policy << source_tclass_pre << endl;	
 						} 
 						//changed here at segatex2.11
@@ -789,6 +795,8 @@ void segatex::segatex_show_interface()
 							source_objclass_pre=source_objclass_pre.replace(length - 1,1,blank_str);
 							/*for debug*/
 							//os_policy << source_objclass_pre << endl;	
+							//2.12ɮäѤꤳѤΤɬפä?
+						        //v_matched_tmp_objclass.push_back(source_objclass_pre.c_str());
 						} 
 						if(regex_search(source_m,what,m_access_vector_exp)){
 							source_access_vector_pre  = what[0];
@@ -831,8 +839,55 @@ void segatex::segatex_show_interface()
 						//const char* m_interface_accv = ":(.*)\\{(.*)\\}";
 						const char* m_interface_accv_pre = ":(.*)\\}";
 						const char* m_interface_accv = "(:[a-z0-9_]*)[[:space:]]";
+						//segatex2.12ɮ
+						const char* m_auth_domtrans = "auth_domtrans";
+						const char* m_bin_domtrans = "bin_domtrans";
+						const char* m_cifs_domtrans = "cifs_domtrans";
+						const char* m_nfs_domtrans = "nfs_domtrans";
+						const char* m_sbin_domtrans = "sbin_domtrans";
+						const char* m_shell_domtrans = "shell_domtrans";
+						const char* m_spec_domtrans = "spec_domtrans";
+						const char* m_boot_filetrans = "boot_filetrans";
+						const char* m_etc_filetrans = "etc_filetrans";
+						const char* m_home_filetrans = "home_filetrans";
+						const char* m_kernel_modules_filetrans = "kernel_modules_filetrans";
+						const char* m_lock_filetrans = "lock_filetrans";
+						const char* m_pid_filetrans = "pid_filetrans";
+						const char* m_tmp_filetrans = "tmp_filetrans";
+						const char* m_var_filetrans = "var_filetrans";
+						const char* m_var_lib_filetrans = "var_lib_filetrans";
+						const char* m_tmpfs_filetrans = "tmpfs_filetrans";
+						const char* m_log_filetrans = "log_filetrans";
+						const char* m_spool_filetrans = "spool_filetrans";
+						const char* m_home_dir_filetrans = "userdom_generic_user_home_dir_filetrans_generic_user_home_content";
+						const char* m_sysadm_home_dir_filetrans = "userdom_sysadm_home_dir_filetrans";
+						const char* m_create_pty = "create_pty";
+						const char* m_cron_system_entry = "cron_system_entry";
 						regex m_interface_accv_exp(m_interface_accv);
 						regex m_interface_accv_pre_exp(m_interface_accv_pre);
+						regex m_auth_domtrans_exp(m_auth_domtrans);
+						regex m_bin_domtrans_exp(m_bin_domtrans);
+						regex m_cifs_domtrans_exp(m_cifs_domtrans);
+						regex m_nfs_domtrans_exp(m_nfs_domtrans);
+						regex m_sbin_domtrans_exp(m_sbin_domtrans);
+						regex m_shell_domtrans_exp(m_shell_domtrans);
+						regex m_spec_domtrans_exp(m_spec_domtrans);
+						regex m_boot_filetrans_exp(m_boot_filetrans);
+						regex m_etc_filetrans_exp(m_etc_filetrans);
+						regex m_home_filetrans_exp(m_home_filetrans);
+						regex m_kernel_modules_filetrans_exp(m_kernel_modules_filetrans);
+						regex m_lock_filetrans_exp(m_lock_filetrans);
+						regex m_pid_filetrans_exp(m_pid_filetrans);
+						regex m_tmp_filetrans_exp(m_tmp_filetrans);
+						regex m_var_filetrans_exp(m_var_filetrans);
+						regex m_var_lib_filetrans_exp(m_var_lib_filetrans);
+						regex m_tmpfs_filetrans_exp(m_tmpfs_filetrans);
+						regex m_log_filetrans_exp(m_log_filetrans);
+						regex m_spool_filetrans_exp(m_spool_filetrans);
+						regex m_home_dir_filetrans_exp(m_home_dir_filetrans);
+						regex m_sysadm_home_dir_filetrans_exp(m_sysadm_home_dir_filetrans);
+						regex m_create_pty_exp(m_create_pty);
+						regex m_cron_system_entry_exp(m_cron_system_entry);
 						string source_interface_accv_pre;
 						string source_interface_accv;
 
@@ -852,8 +907,7 @@ void segatex::segatex_show_interface()
 							if(regex_search(source_m_engine,what,m_interface_engine_exp)){
 								source_interface_engine  = what[0];
 								//segatex2.05ɮ꤬狼ätmp_t:fileȤĤxxx_tmp_t:fileˤääƤޤΤǤ롣ȤȤǡΤ褦ˡϤ˶դƸƤߤ
-								//os_policy << source_interface_pre ;
-								//os_policy << " matched !!" << endl;
+								//os_policy << source_interface_pre << " matched !!" << endl;
 								
 								/*interface all sentence*/
 								//os_policy << source_macro_engine << endl;
@@ -886,18 +940,23 @@ void segatex::segatex_show_interface()
 										if( !regex_search(it, end, result, tmp_re)){
 											break;
 										}
-										//os_policy << "interface_core<" << source_interface_accv << ":" << result.str() << ">" << endl;
-										pattern_matched_access_vector.insert(pair<string, string>(source_interface_accv,result.str()));
+										if(result.str() !=" "){
+											pattern_matched_access_vector.insert(pair<string, string>(source_interface_accv,result.str()));
+											//os_policy << "interface_core<" << source_interface_accv << ":" << result.str() << ">" << endl;
+										}
 										it = result[0].second;
 									}
 								}
 								/*󥿥եλobjectclassΥ٥ѤߤϤޤ*/
+								//2.12ɮ󥿥ե򸡺
 								if(regex_search( source_macro_engine, re )){
 									string::const_iterator it=source_macro_engine.begin(), end=source_macro_engine.end();
 									int i=0;
 									string check_str = ":";
 									string bracket_first_str = "(";
 									string bracket_last_str = ")";
+									string comma_str = ",";
+									string private_type = "file";
 									while( it != end){
 										//ޥåսƬ
 										smatch result;
@@ -914,6 +973,7 @@ void segatex::segatex_show_interface()
 											if(length >1){
 												string blank_str="";
 												string interface_raw_str=result.str().replace(length -1,1,blank_str);
+												//ǥ󥿥եȤƤ
 												v_interface_raw.push_back(interface_raw_str.c_str());
 												//os_policy << interface_raw_str << ":" <<endl;
 												p_pattern_not_matched_domain=pattern_not_matched_domain.find(source_interface_pre);
@@ -922,12 +982,220 @@ void segatex::segatex_show_interface()
 														int length=strlen(result.str().c_str());
 														string blank_str="";
 														string result_str=result.str().replace(length -1,1,blank_str);
-														
-														//string domain_interface_echo = result.str() + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
-														string domain_interface_echo = result_str + bracket_first_str + p_pattern_not_matched_domain->second + bracket_last_str;  
+														string domain_dollar_1;
+														string domain_dollar_2;
+														string domain_interface_echo;
+														domain_dollar_1=p_pattern_not_matched_domain->second;
+														//2.12ɮ
+														//륤󥿥եϡ򣲤ɬפȤ롣domtransξ
+														cmatch what;
+														if((regex_search(result_str.c_str(),what,m_auth_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_bin_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_cifs_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_nfs_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_sbin_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_shell_domtrans_exp))||
+														(regex_search(result_str.c_str(),what,m_spec_domtrans_exp))
+														){
+															string domtransed="_domtransed_t";
+															//os_policy << "oohps !" << endl;
+															domain_dollar_2=p_pattern_not_matched_domain->second;
+															int length=strlen(domain_dollar_2.c_str());
+															domain_dollar_2=domain_dollar_2.replace(length -2,2,blank_str);
+															domain_dollar_2= domain_dollar_2 + domtransed;
+											
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															//¤ʤʤΤƤΤǡŪѤǤ
+string pair_process="process";
+string paired_transition="transition";
+string paired_siginh="siginh";
+string paired_rlimitinh="rlimitinh";
+string paired_noatsecure="noatsecure";
+
+string pair_association="association";
+string paired_sendto="sendto";
+string paired_recvfrom="recvfrom";
+
+string pair_packet="packet";
+string paired_send="send";
+string paired_recv="recv";
+
+string pair_netif="netif";
+string paired_tcp_send="tcp_send";
+string paired_tcp_recv="tcp_recv";
+string paired_udp_send="udp_send";
+string paired_udp_recv="udp_recv";
+
+string pair_node="node";
+
+string pair_tcp_socket="tcp_socket";
+string paired_send_msg="send_msg";
+string paired_recv_msg="recv_msg";
+string paired_node_bind="node_bind";
+string paired_name_bind="name_bind";
+string paired_name_connect="name_connect";
+
+string pair_udp_socket="udp_socket";
+
+string pair_capability="capability";
+string paired_net_bind_service="net_bind_service";
+
+string pair_security="security";
+string paired_setbool="setbool";
+string paired_setenforce="setenforce";
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_transition));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_siginh));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_rlimitinh));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_noatsecure));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_association,paired_sendto));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_association,paired_recvfrom));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_packet,paired_sendto));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_packet,paired_recvfrom));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_packet,paired_send));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_packet,paired_recv));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_sendto));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_recvfrom));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_tcp_send));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_tcp_recv));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_udp_send));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_netif,paired_udp_recv));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_node,paired_tcp_send));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_node,paired_tcp_recv));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_node,paired_udp_send));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_node,paired_udp_recv));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_send_msg));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_recv_msg));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_node_bind));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_name_bind));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_name_connect));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_send_msg));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_recv_msg));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_node_bind));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_name_bind));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_node_bind));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_capability,paired_net_bind_service));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_security,paired_setbool));
+															pattern_not_matched_access_vector.insert(pair<string, string>(pair_security,paired_setenforce));
+															//ѤǤɬפΤ
+						        								v_matched_tmp_objclass.push_back(pair_process.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_association.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_packet.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_netif.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_node.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_tcp_socket.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_udp_socket.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_capability.c_str());
+						        								v_matched_tmp_objclass.push_back(pair_security.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + bracket_last_str;  
+														//boot_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_boot_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="boot_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//etc_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_etc_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="etc_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//home_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_home_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="home_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//kernel_modules_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_kernel_modules_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="kernel_modules_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//lock_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_lock_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="lock_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//pid_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_pid_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="pid_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//tmp_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_tmp_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															string tmp_filetrans_echo="tmp_runtime_t";
+															domain_dollar_2=p_pattern_not_matched_domain->second;
+															int length=strlen(domain_dollar_2.c_str());
+															domain_dollar_2=domain_dollar_2.replace(length -2,2,blank_str);
+															domain_dollar_2= domain_dollar_2 + tmp_filetrans_echo;
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//var_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_var_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="var_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//var_lib_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_var_lib_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="var_lib_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//tmpfs_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_tmpfs_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="tmpfs_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//log_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_log_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="log_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//spool_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_spool_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="spool_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//home_dir_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_home_dir_filetrans_exp)){
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + private_type + bracket_last_str;  
+														//sysadm_home_dir_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_sysadm_home_dir_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="sysadm_home_dir_runtime_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//create_ptyξ
+														}else if(regex_search(result_str.c_str(),what,m_create_pty_exp)){
+															//os_policy << "oohps !" << endl;
+															string filetransed="_pty_t";
+															domain_dollar_2=p_pattern_not_matched_domain->second;
+															int length=strlen(domain_dollar_2.c_str());
+															domain_dollar_2=domain_dollar_2.replace(length -2,2,blank_str);
+															domain_dollar_2= domain_dollar_2 + filetransed;
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + bracket_last_str;  
+														//üʾ
+														}else if(regex_search(result_str.c_str(),what,m_cron_system_entry_exp)){
+															domain_dollar_2="anacron_exec_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + bracket_last_str;  
+														}else{
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + bracket_last_str;  
+														}
 														//ǥ󥿥ե(ɥᥤ)ѤǤ
+														//segatex2.12ɮȯdomtrans󥿥եξν֤ɤ뤫
 														v_domain_interface.push_back(domain_interface_echo.c_str());
-														//os_policy << result.str() << "(" << p_pattern_not_matched_domain->second << ")" << endl;
+														//os_policy << domain_interface_echo << endl;
 														p_pattern_not_matched_domain++;
 													}while(p_pattern_not_matched_domain != pattern_not_matched_domain.upper_bound(source_interface_pre));
 												}
@@ -1212,35 +1480,43 @@ void segatex::segatex_show_interface()
 						//os_policy << "test:" << test << endl;
 					}
 					/*ˡ¦ǤmultimapޤȤ*/
+					//2.12ɮ褦䡢ɤ߽ФȤ˰ĤʤΤɤ߽Фʤ
 					/*multimapΥƥ졼Ȥä...*/
+					//int test_size=pattern_not_matched_access_vector.size();
+					//os_policy << "test_size:" << test_size << endl << endl;
+					//int test_size3=pattern_matched_access_vector.size();
+					//os_policy << "test_size3:" << test_size3 << endl << endl;
 					p_pattern_matched_access_vector=pattern_matched_access_vector.begin();
 					do{
 
 						string objclass_matched_echo = p_pattern_matched_access_vector->first;
 						string accv_matched_echo = p_pattern_matched_access_vector->second;
 						//segatex2.05ʤǤΤȯϾɡ
-						//os_policy << "final<" << objclass_matched_echo << ":" << accv_matched_echo << ">" << endl;
 						string blank_str="";
 						string space_first_str=" ";
 						int length=strlen(objclass_matched_echo.c_str());
 						objclass_matched_echo=objclass_matched_echo.replace(length -1,1,blank_str);
 						int space_first_position=accv_matched_echo.find_first_of(space_first_str);
 						accv_matched_echo=accv_matched_echo.replace(0,space_first_position + 1,blank_str);
+						//os_policy << "final<" << objclass_matched_echo << ":" << accv_matched_echo << ">" << endl;
 						pattern_not_matched_access_vector.insert(pair<string, string>(objclass_matched_echo,accv_matched_echo));
 						p_pattern_matched_access_vector++;
 					}while(p_pattern_matched_access_vector != pattern_matched_access_vector.end());
+					//int test_size2=pattern_not_matched_access_vector.size();
+					//os_policy << "test_size2:" << test_size2 << endl << endl;
 
 					sort(v_tmp_objclass.begin(),v_tmp_objclass.end());
 					p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 					os_policy << "####################################################" << endl;
-					os_policy << "##### This file was generated by segatex2.11" << endl;
+					os_policy << "##### This file was generated by segatex2.12" << endl;
 					os_policy << "####################################################" << endl;
 					os_policy << "module my_policy_by_segatex 1.0.0;" << endl << endl;
 					os_policy << "require {" << endl;
 					string p_pattern_not_matched_objclass_pre=*v_tmp_objclass.begin();
 					for(p_tmp_objclass=v_tmp_objclass.begin(); p_tmp_objclass < p_tmp_objclass_end; p_tmp_objclass++){
 						string tmp_str= *p_tmp_objclass;
+						string v_accv_pre_one_str="";
 						string v_accv_pre_str="";
 						//os_policy << "tmp_str:" << tmp_str << endl;
 						/*ǤϡޥåʤäΤȡΤȡ󥿥եäƤobjclassaccess_vectorƳФƤ*/
@@ -1248,14 +1524,38 @@ void segatex::segatex_show_interface()
 						if(p_pattern_not_matched_access_vector != pattern_not_matched_access_vector.end()){
 							os_policy << "	class " << p_pattern_not_matched_access_vector->first << " { " ;
 							do{
+										//2.12ɮfor debugǤƤȤȤϡ
+										//os_policy << "second_check:" << p_pattern_not_matched_access_vector->second << endl;
+								//2.12ɮĤʤ
+								v_accv_pre_one_str=p_pattern_not_matched_access_vector->second;
+								//os_policy << v_accv_pre_one_str << " ";
+								//added in seagtex2.11{}ʧ
+								int bracket_first_position=-1;
+								int bracket_last_position=-1;
+								bracket_first_position=v_accv_pre_one_str.find("{");
+								if(bracket_first_position != -1){
+									//os_policy << bracket_first_position << "found bracket_first_str !!" << endl;	
+									v_accv_pre_one_str=v_accv_pre_one_str.replace(bracket_first_position,2,blank_str);
+								}
+								bracket_last_position=v_accv_pre_one_str.find("}");
+								if(bracket_last_position != -1){
+									//os_policy << bracket_last_position << "found bracket_last_str !!" << endl;	
+									v_accv_pre_str=v_accv_pre_one_str.replace(bracket_last_position,2,blank_str);
+								}
+								//os_policy << v_accv_pre_one_str << " ";
+								v_accv.push_back(v_accv_pre_one_str.c_str());
 								if(p_pattern_not_matched_access_vector->first == p_pattern_not_matched_objclass_pre){
 									/*Τʤ褦*/
 									cmatch what;
 									regex tmp_re3("(.*)\\$(.*)");
 									if(regex_search(p_pattern_not_matched_access_vector->second.c_str(),what,tmp_re3)){
 										/*⤷ʤ*/
+										//string tmp_str;
+										//tmp_str=what[0];
+										//os_policy << "tmp_str:"<< tmp_str << endl;
 									}else{
 										v_accv_pre_str=p_pattern_not_matched_access_vector->second;
+										//os_policy << v_accv_pre_str << " ";
 										//added in seagtex2.11{}ʧ
 										int bracket_first_position=-1;
 										int bracket_last_position=-1;
@@ -1295,6 +1595,14 @@ void segatex::segatex_show_interface()
 						string test = v_matched_tmp_domain[i];
 						//os_policy << test << endl;
 					}
+					//segatex2.12ɮ
+					/*ˡܺѤߥɥᥤޤȤƤ*/
+					int v_dollar_2_domain_size=v_dollar_2_domain.size();
+					for(int i=0;i < v_dollar_2_domain_size;i++){
+						v_tmp_domain.push_back(v_dollar_2_domain[i].c_str());
+						string test = v_dollar_2_domain[i];
+						//os_policy << test << endl;
+					}
 					sort(v_tmp_domain.begin(),v_tmp_domain.end());
 					p_tmp_domain_end=unique(v_tmp_domain.begin(),v_tmp_domain.end());
 					for(p_tmp_domain=v_tmp_domain.begin();p_tmp_domain < p_tmp_domain_end; p_tmp_domain++){
@@ -1346,7 +1654,7 @@ void segatex::segatex_show_interface()
 					string p_allow_first_str=*v_allow_first.begin();
 					for(p_allow_first=v_allow_first.begin(); p_allow_first < p_allow_first_end; p_allow_first++){
 						string tmp_str= *p_allow_first;
-						//os_policy << "tmp_str" << tmp_str << endl;
+						//os_policy << "tmp_str:" << tmp_str << endl;
 						p_pattern_allow_not_matched_echo=pattern_allow_not_matched_echo.find(tmp_str);
 						if(p_pattern_allow_not_matched_echo != pattern_allow_not_matched_echo.end()){
 							//ո©ɡޤ
